texlive[62062] trunk: texfot (17feb22)

commits+karl at tug.org commits+karl at tug.org
Thu Feb 17 22:48:01 CET 2022


Revision: 62062
          http://tug.org/svn/texlive?view=revision&revision=62062
Author:   karl
Date:     2022-02-17 22:48:01 +0100 (Thu, 17 Feb 2022)
Log Message:
-----------
texfot (17feb22)

Modified Paths:
--------------
    trunk/Build/source/texk/texlive/linked_scripts/texfot/texfot.pl
    trunk/Master/texmf-dist/doc/man/man1/texfot.1
    trunk/Master/texmf-dist/doc/man/man1/texfot.man1.pdf
    trunk/Master/texmf-dist/scripts/texfot/texfot.pl

Modified: trunk/Build/source/texk/texlive/linked_scripts/texfot/texfot.pl
===================================================================
--- trunk/Master/texmf-dist/doc/man/man1/texfot.1	2022-02-17 21:47:27 UTC (rev 62061)
+++ trunk/Master/texmf-dist/doc/man/man1/texfot.1	2022-02-17 21:48:01 UTC (rev 62062)
@@ -1,4 +1,4 @@
-.\" Automatically generated by Pod::Man 4.14 (Pod::Simple 3.40)
+.\" Automatically generated by Pod::Man 4.14 (Pod::Simple 3.42)
 .\"
 .\" Standard preamble:
 .\" ========================================================================
@@ -133,7 +133,7 @@
 .\" ========================================================================
 .\"
 .IX Title "TEXFOT 1"
-.TH TEXFOT 1 "2021-05-01" "texfot" "Karl Berry"
+.TH TEXFOT 1 "2022-02-17" "texfot" "Karl Berry"
 .\" For nroff, turn off justification.  Always turn off hyphenation; it makes
 .\" way too many mistakes in technical documents.
 .if n .ad l
@@ -153,8 +153,8 @@
 \&  # Sample basic invocation:
 \&  texfot pdflatex file.tex
 \&  
-\&  # Ordinarily all output is copied to /tmp/fot before filtering,
-\&  # but that can be omitted:
+\&  # Ordinarily the full output is copied to /tmp/fot.$UID before
+\&  # filtering, but that can be omitted, or the filename changed:
 \&  texfot \-\-tee=/dev/null lualatex file.tex
 \&  
 \&  # Example of more complex engine invocation:
@@ -285,11 +285,15 @@
 .el .IP "\f(CW\-\-tee\fR \fIfile\fR" 4
 .IX Item "--tee file"
 By default, the output being filtered is \f(CW\*(C`tee\*(C'\fR\-ed, before filtering, to
-\&\f(CW\*(C`$TMPDIR/fot\*(C'\fR (or \f(CW\*(C`$TMP/fot\*(C'\fR if \f(CW\*(C`TMP\*(C'\fR is set, or \f(CW\*(C`/tmp/fot\*(C'\fR if
-neither environment variable is set), to make it easy to check the full
-output when the filtering seems suspect. This option allows specifying a
-different file. Use \f(CW\*(C`\-\-tee\ /dev/null\*(C'\fR if you don't want the original
-output at all.
+make it easy to check the full output in case of problems.
+.Sp
+The default \fIfile\fR is \f(CW\*(C`$TMPDIR/fot.\*(C'\fR\fIuid\fR; if \f(CW\*(C`TMPDIR\*(C'\fR is not set,
+\&\f(CW\*(C`TMP\*(C'\fR is used if set; if neither is set, the default directory is
+\&\f(CW\*(C`/tmp\*(C'\fR. For example: \f(CW\*(C`/tmp/fot.1001\*(C'\fR. The \fIuid\fR suffix is the
+effective userid of the process, appended for basic avoidance of
+collisions between different users on the same system.
+.Sp
+This option allows specifying a different file. Use \f(CW\*(C`\-\-tee\ /dev/null\*(C'\fR to discard the original output.
 .ie n .IP """\-\-version""" 4
 .el .IP "\f(CW\-\-version\fR" 4
 .IX Item "--version"
@@ -302,7 +306,7 @@
 .IX Header "RATIONALE"
 I wrote this because, in my work as a TUGboat editor
 (<https://tug.org/TUGboat>, journal submissions always welcome!), I run
-and rerun many documents, many times each. It was too easy to lose
+and rerun many documents, many times each. It was easy to lose
 warnings I needed to see in the mass of unvarying and uninteresting
 output from TeX, such as style files being read and fonts being used. I
 wanted to see all and only those messages which needed some action by
@@ -322,7 +326,7 @@
 .PP
 \&\f(CW\*(C`texfot\*(C'\fR is written in Perl, and runs on Unix. It may work on Windows
 if Perl and other software is installed, but I don't use Windows and
-don't support C,texfot> there.
+don't support \f(CW\*(C`texfot\*(C'\fR there.
 .PP
 The name comes from the \f(CW\*(C`trip.fot\*(C'\fR and \f(CW\*(C`trap.fot\*(C'\fR files that are part
 of Knuth's trip and trap torture tests, which record the online output
@@ -335,3 +339,7 @@
 are released to the public domain.  Email \f(CW\*(C`karl at freefriends.org\*(C'\fR with
 bug reports.  It has no home page beyond the package on \s-1CTAN:\s0
 <https://ctan.org/pkg/texfot>.
+.PP
+.Vb 1
+\&  $Id: texfot,v 1.45 2022/02/17 18:42:02 karl Exp $
+.Ve

Modified: trunk/Master/texmf-dist/doc/man/man1/texfot.man1.pdf
===================================================================
(Binary files differ)

Modified: trunk/Master/texmf-dist/scripts/texfot/texfot.pl
===================================================================
--- trunk/Build/source/texk/texlive/linked_scripts/texfot/texfot.pl	2022-02-17 21:47:27 UTC (rev 62061)
+++ trunk/Build/source/texk/texlive/linked_scripts/texfot/texfot.pl	2022-02-17 21:48:01 UTC (rev 62062)
@@ -1,14 +1,14 @@
 #!/usr/bin/env perl
-# $Id: texfot,v 1.43 2021/05/01 15:49:53 karl Exp $
+# $Id: texfot,v 1.45 2022/02/17 18:42:02 karl Exp $
 # Invoke a TeX command, filtering all but interesting terminal output;
 # do not look at the log or check any output files.
 # Exit status is that of the subprogram.
 # Tee the complete (unfiltered) standard output and standard error to
-# (by default) /tmp/fot.
+# (by default) /tmp/fot.$UID.
 # 
 # Public domain.  Originally written 2014 by Karl Berry.
 
-my $ident = '$Id: texfot,v 1.43 2021/05/01 15:49:53 karl Exp $';
+my $ident = '$Id: texfot,v 1.45 2022/02/17 18:42:02 karl Exp $';
 (my $prg = $0) =~ s,^.*/,,;
 select STDERR; $| = 1;  # no buffering
 select STDOUT; $| = 1;
@@ -26,7 +26,7 @@
 my $opt_interactive = 0;
 my $opt_quiet = 0;
 my $opt_stderr = 1;
-my $opt_tee = ($ENV{"TMPDIR"} || $ENV{"TMP"} || "/tmp") . "/fot";
+my $opt_tee = ($ENV{"TMPDIR"} || $ENV{"TMP"} || "/tmp") . "/fot.$>";
 my $opt_version = 0;
 my $opt_help = 0;
 
@@ -135,6 +135,7 @@
      |LaTeX\ Font\ Warning:\ Some\ font\ shapes
      |LaTeX\ Font\ Warning:\ Size\ substitutions
      |Package\ auxhook\ Warning:\ Cannot\ patch
+     |Package\ biditools\ Warning:\ Patching
      |Package\ caption\ Warning:\ Un(supported|known)\ document\ class
      |Package\ fixltx2e\ Warning:\ fixltx2e\ is\ not\ required
      |Package\ frenchb?\.ldf\ Warning:\ (Figures|The\ definition)
@@ -230,8 +231,8 @@
   # Sample basic invocation:
   texfot pdflatex file.tex
   
   # Ordinarily all output is copied to /tmp/fot before filtering,
   # but that can be omitted:
   texfot --tee=/dev/null lualatex file.tex
   
   # Example of more complex engine invocation:
@@ -367,12 +368,17 @@
 =item C<--tee> I<file>
 
 By default, the output being filtered is C<tee>-ed, before filtering, to
-C<$TMPDIR/fot> (or C<$TMP/fot> if C<TMP> is set, or C</tmp/fot> if
-neither environment variable is set), to make it easy to check the full
-output when the filtering seems suspect. This option allows specifying a
-different file. Use S<C<--tee /dev/null>> if you don't want the original
-output at all.
+make it easy to check the full output in case of problems. 
 
+The default I<file> is C<$TMPDIR/fot.>I<uid>; if C<TMPDIR> is not set,
+C<TMP> is used if set; if neither is set, the default directory is
+C</tmp>. For example: C</tmp/fot.1001>. The I<uid> suffix is the
+effective userid of the process, appended for basic avoidance of
+collisions between different users on the same system.
+
+This option allows specifying a different file. Use S<C<--tee
+/dev/null>> to discard the original output.
+
 =item C<--version>
 
 Output version information and exit successfully.
@@ -387,7 +393,7 @@
 
 I wrote this because, in my work as a TUGboat editor
 (L<https://tug.org/TUGboat>, journal submissions always welcome!), I run
-and rerun many documents, many times each. It was too easy to lose
+and rerun many documents, many times each. It was easy to lose
 warnings I needed to see in the mass of unvarying and uninteresting
 output from TeX, such as style files being read and fonts being used. I
 wanted to see all and only those messages which needed some action by
@@ -407,7 +413,7 @@
 
 C<texfot> is written in Perl, and runs on Unix. It may work on Windows
 if Perl and other software is installed, but I don't use Windows and
-don't support C,texfot> there.
+don't support C<texfot> there.
 
 The name comes from the C<trip.fot> and C<trap.fot> files that are part
 of Knuth's trip and trap torture tests, which record the online output
@@ -422,4 +428,6 @@
 bug reports.  It has no home page beyond the package on CTAN:
 L<https://ctan.org/pkg/texfot>.
 
+  $Id: texfot,v 1.45 2022/02/17 18:42:02 karl Exp $
+
 =cut
@@ -230,8 +231,8 @@
   texfot pdflatex file.tex
   
-  # Ordinarily all output is copied to /tmp/fot before filtering,
-  # but that can be omitted:
+  # Ordinarily the full output is copied to /tmp/fot.$UID before
+  # filtering, but that can be omitted, or the filename changed:
   texfot --tee=/dev/null lualatex file.tex
   

Modified: trunk/Master/texmf-dist/doc/man/man1/texfot.1
===================================================================
--- trunk/Master/texmf-dist/scripts/texfot/texfot.pl	2022-02-17 21:47:27 UTC (rev 62061)
+++ trunk/Master/texmf-dist/scripts/texfot/texfot.pl	2022-02-17 21:48:01 UTC (rev 62062)
@@ -1,14 +1,14 @@
 #!/usr/bin/env perl
-# $Id: texfot,v 1.43 2021/05/01 15:49:53 karl Exp $
+# $Id: texfot,v 1.45 2022/02/17 18:42:02 karl Exp $
 # Invoke a TeX command, filtering all but interesting terminal output;
 # do not look at the log or check any output files.
 # Exit status is that of the subprogram.
 # Tee the complete (unfiltered) standard output and standard error to
-# (by default) /tmp/fot.
+# (by default) /tmp/fot.$UID.
 # 
 # Public domain.  Originally written 2014 by Karl Berry.
 
-my $ident = '$Id: texfot,v 1.43 2021/05/01 15:49:53 karl Exp $';
+my $ident = '$Id: texfot,v 1.45 2022/02/17 18:42:02 karl Exp $';
 (my $prg = $0) =~ s,^.*/,,;
 select STDERR; $| = 1;  # no buffering
 select STDOUT; $| = 1;
@@ -26,7 +26,7 @@
 my $opt_interactive = 0;
 my $opt_quiet = 0;
 my $opt_stderr = 1;
-my $opt_tee = ($ENV{"TMPDIR"} || $ENV{"TMP"} || "/tmp") . "/fot";
+my $opt_tee = ($ENV{"TMPDIR"} || $ENV{"TMP"} || "/tmp") . "/fot.$>";
 my $opt_version = 0;
 my $opt_help = 0;
 
@@ -135,6 +135,7 @@
      |LaTeX\ Font\ Warning:\ Some\ font\ shapes
      |LaTeX\ Font\ Warning:\ Size\ substitutions
      |Package\ auxhook\ Warning:\ Cannot\ patch
+     |Package\ biditools\ Warning:\ Patching
      |Package\ caption\ Warning:\ Un(supported|known)\ document\ class
      |Package\ fixltx2e\ Warning:\ fixltx2e\ is\ not\ required
      |Package\ frenchb?\.ldf\ Warning:\ (Figures|The\ definition)
@@ -230,8 +231,8 @@
   # Sample basic invocation:
   texfot pdflatex file.tex
   
   # Ordinarily all output is copied to /tmp/fot before filtering,
   # but that can be omitted:
   texfot --tee=/dev/null lualatex file.tex
   
   # Example of more complex engine invocation:
@@ -367,12 +368,17 @@
 =item C<--tee> I<file>
 
 By default, the output being filtered is C<tee>-ed, before filtering, to
-C<$TMPDIR/fot> (or C<$TMP/fot> if C<TMP> is set, or C</tmp/fot> if
-neither environment variable is set), to make it easy to check the full
-output when the filtering seems suspect. This option allows specifying a
-different file. Use S<C<--tee /dev/null>> if you don't want the original
-output at all.
+make it easy to check the full output in case of problems. 
 
+The default I<file> is C<$TMPDIR/fot.>I<uid>; if C<TMPDIR> is not set,
+C<TMP> is used if set; if neither is set, the default directory is
+C</tmp>. For example: C</tmp/fot.1001>. The I<uid> suffix is the
+effective userid of the process, appended for basic avoidance of
+collisions between different users on the same system.
+
+This option allows specifying a different file. Use S<C<--tee
+/dev/null>> to discard the original output.
+
 =item C<--version>
 
 Output version information and exit successfully.
@@ -387,7 +393,7 @@
 
 I wrote this because, in my work as a TUGboat editor
 (L<https://tug.org/TUGboat>, journal submissions always welcome!), I run
-and rerun many documents, many times each. It was too easy to lose
+and rerun many documents, many times each. It was easy to lose
 warnings I needed to see in the mass of unvarying and uninteresting
 output from TeX, such as style files being read and fonts being used. I
 wanted to see all and only those messages which needed some action by
@@ -407,7 +413,7 @@
 
 C<texfot> is written in Perl, and runs on Unix. It may work on Windows
 if Perl and other software is installed, but I don't use Windows and
-don't support C,texfot> there.
+don't support C<texfot> there.
 
 The name comes from the C<trip.fot> and C<trap.fot> files that are part
 of Knuth's trip and trap torture tests, which record the online output
@@ -422,4 +428,6 @@
 bug reports.  It has no home page beyond the package on CTAN:
 L<https://ctan.org/pkg/texfot>.
 
+  $Id: texfot,v 1.45 2022/02/17 18:42:02 karl Exp $
+
 =cut
@@ -230,8 +231,8 @@
   texfot pdflatex file.tex
   
-  # Ordinarily all output is copied to /tmp/fot before filtering,
-  # but that can be omitted:
+  # Ordinarily the full output is copied to /tmp/fot.$UID before
+  # filtering, but that can be omitted, or the filename changed:
   texfot --tee=/dev/null lualatex file.tex
   



More information about the tex-live-commits mailing list.